@@ -2,38 +2,41 @@
 
 At least 3 of these characters on a line * - _
 """
+
 import logging
 
-from ..common.utils import isSpace
+from ..common.utils import isStrSpace
 from .state_block import StateBlock
 
 LOGGER = logging.getLogger(__name__)
 
 
-def hr(state: StateBlock, startLine: int, endLine: int, silent: bool):
+def hr(state: StateBlock, startLine: int, endLine: int, silent: bool) -> bool:
     LOGGER.debug("entering hr: %s, %s, %s, %s", state, startLine, endLine, silent)
 
     pos = state.bMarks[startLine] + state.tShift[startLine]
     maximum = state.eMarks[startLine]
 
-    # if it's indented more than 3 spaces, it should be a code block
-    if state.sCount[startLine] - state.blkIndent >= 4:
+    if state.is_code_block(startLine):
         return False
 
-    marker = state.srcCharCode[pos]
+    try:
+        marker = state.src[pos]
+    except IndexError:
+        return False
     pos += 1
 
-    # Check hr marker: /* * */ /* - */ /* _ */
-    if marker != 0x2A and marker != 0x2D and marker != 0x5F:
+    # Check hr marker
+    if marker not in ("*", "-", "_"):
         return False
 
     # markers can be mixed with spaces, but there should be at least 3 of them
 
     cnt = 1
     while pos < maximum:
-        ch = state.srcCharCode[pos]
+        ch = state.src[pos]
         pos += 1
-        if ch != marker and not isSpace(ch):
+        if ch != marker and not isStrSpace(ch):
             return False
         if ch == marker:
             cnt += 1
@@ -48,6 +51,6 @@ def hr(state: StateBlock, startLine: int, endLine: int, silent: bool):
 
     token = state.push("hr", "hr", 0)
     token.map = [startLine, state.line]
-    token.markup = chr(marker) * (cnt + 1)
+    token.markup = marker * (cnt + 1)
 
     return True
